[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![Versions](https://img.shields.io/pypi/pyversions/pygus)]()



# gus
![GUS-IMAGE](https://miro.medium.com/max/1400/1*fMM7rnq1RJCh-nFBGLUvyA.png)

Green Urban Scenarios - A digital twin representation, simulation of urban forests and their impact analysis.

## Getting Started
Visit the GUS [website documentation](https://lucidmindsai.github.io/gus/) for help with installing GUS, code documentation, and a [basic tutorial](https://github.com/lucidmindsai/gus/blob/main/notebooks/Tutorial.ipynb) to get you started. 

## Install from PyPi
We publish GUS as `pyGus` package in PyPi. Dependencies can be found in the .toml file on the GUS GitHub page. Even though installation with Poetry is possible, the most stable installation can be done via pip.

```
$ pip install pygus
```

For further instructions and code documentation, visit [GUS Code Documentation](https://lucidmindsai.github.io/gus/)

### Who maintains GUS?
The GUS is currently developed and maintained by [Lucidminds](https://lucidminds.ai/) and [Dark Matter Labs](https://darkmatterlabs.org/) members as part of their joint project [TreesAI](https://treesasinfrastructure.com/#/).

### Notes
* The GUS is open for PRs.
* PRs will be reviewed by the current maintainers of the project.
* Extensive development guidelines will be provided soon.
* To report bugs, fixes, and questions, please use the [GitHub issues](https://github.com/lucidmindsai/gus/issues).